<template>
  <headerBar></headerBar>
  <router-view/> 
  <footerBar></footerBar>
</template>

<script setup>
import { ref, provide, onMounted } from 'vue';

const isLogged = ref(false);
provide('isLogged', isLogged);

async function checkSession(){
  let sid = localStorage.getItem('sid');
  if(!sid){
    localStorage.removeItem('user')
    isLogged.value = false;
    return;
  }
  try {
    let response = await get(`/api/auth/check-session`, {sid: sid})
    let data = await response.json();
    if (response.ok) {
      // console.log(data);
      isLogged.value = true;
      localStorage.setItem('user', JSON.stringify(data.user));
    } else {
      localStorage.removeItem('sid')
      localStorage.removeItem('user')
      console.error('Error:', data);
      isLogged.value = false;
      alert('Registration failed: ' + data.message);
    }
  } catch (error) {
    localStorage.removeItem('sid')
    localStorage.removeItem('user')
    isLogged.value = false;
    console.error('There has been a problem with your fetch operation:', error);
    alert('An error occurred: ' + error.message);
  }
}

function refreshSession() {
  checkSession();
  setTimeout(() => {
    refreshSession();
  }, 100000);
};
provide('refreshSession', refreshSession);

onMounted(async () => {
  if(localStorage.getItem('sid')){
    refreshSession();
  }
});
</script>

